@@ -205,9 +205,11 @@ pub use vsdb_derive::Vs;
 #[cfg(feature = "merkle")]
 pub use merkle::MerkleTree;
 
+#[cfg(feature = "hash")]
+pub use common::utils::hash::{hash, Hash, HASH_SIZ};
+
 pub use common::{
     ende::{KeyDe, KeyEn, KeyEnDe, KeyEnDeOrdered, ValueDe, ValueEn, ValueEnDe},
-    utils::{hash, Hash, HASH_SIZ},
     vsdb_flush, vsdb_get_base_dir, vsdb_get_custom_dir, vsdb_set_base_dir, BranchName,
     ParentBranchName, VersionName, GB, INITIAL_VERSION, KB, MB,
 };
